#
# spec file for package inih
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020 Matthias Bach <marix@marix.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           inih
Version:        58
Release:        1.4
Summary:        Simple .INI file parser in C, good for embedded systems
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/benhoyt/inih
Source:         https://github.com/benhoyt/inih/archive/r%{version}.tar.gz#/inih-r%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkgconfig

%description
INI Not Invented Here is a simple parser for .INI files written in C and mostly
compatible with Python's ConfigParser.

%package -n libinih0
Summary:        INIH dynamic libary files
Group:          System/Libraries

%description -n libinih0
INI Not Invented Here is a simple parser for .INI files written in C and mostly
compatible with Python's ConfigParser.

This package provides the library for use at runtime by applications using INIH.

%package -n libinih-devel
Summary:        Development files for INIH
Group:          Development/Libraries/C and C++
Requires:       libinih0 = %{version}

%description -n libinih-devel
INI Not Invented Here is a simple parser for .INI files written in C and mostly
compatible with Python's ConfigParser.

This package provides the development headers for INIH including the C++ bindings.

%prep
%setup -q -n %{name}-r%{version}

%build
%meson -Ddefault_library=shared -Ddistro_install=true -Dwith_INIReader=true
%meson_build

%check
cd tests
bash -e ./unittest.sh
cd ../examples
bash -e cpptest.sh

%install
%meson_install

%post -n libinih0 -p /sbin/ldconfig
%postun -n libinih0 -p /sbin/ldconfig

%files -n libinih0
%{_libdir}/libinih.so.*
%{_libdir}/libINIReader.so.*
%license LICENSE.txt

%files -n libinih-devel
%{_includedir}/ini.h
%{_includedir}/INIReader.h
%{_libdir}/libinih.so
%{_libdir}/libINIReader.so
%{_libdir}/pkgconfig/inih.pc
%{_libdir}/pkgconfig/INIReader.pc
%doc README.md
%license LICENSE.txt

%changelog
* Thu Jan 25 2024 Matthias Bach <marix@marix.org> - 58
- Update to version 58
  * Add ini_ prefix even to static names so inih can be used as an
    [#]include.
* Fri Jul  7 2023 Matthias Bach <marix@marix.org> - 57
- Update to version 57
  * Added a GetUnsigned function for getting unsigned values.
  * Added GetInteger64 and GetUnsigned64 to read 64-bit integers.
* Sat Jul 16 2022 Matthias Bach <marix@marix.org> - 56
- Update to version 56
  * Fix redundant cast-to-int when INI_USE_STACK!=0
  * Make inline comments work on subsequent lines of multiline values
* Fri Mar 25 2022 Matthias Bach <marix@marix.org> - 55
- Update to version 55
  * Include proper version in installed pkgconfig files.
* Fri Mar 25 2022 Matthias Bach <marix@marix.org> - 54
- Update to version 54
  * Improve quality of shared objects by explicitly defining symbol
    visibility.
* Thu Mar 11 2021 Wang Jun <jgwang@suse.com> - 53
  ￼
- Update to version 53
  * Add architecture ppc64le to travis build (#122)
  * enable distro settings by default (#125)
  * meson: optionally depend on c++ (#124)
  * meson: add static compile args to inih_dep (#126)
* Thu Dec 24 2020 Matthias Bach <marix@marix.org> - 52
- Make package conform to spec-cleaner.
* Thu Oct 15 2020 Matthias Bach <marix@marix.org> - 52
- Update to version 52
  * Add INI_CUSTOM_ALLOCATOR to allow using a custom memory
    allocator.
- Drop workaround for library name not matching its soname as this
  was fixed upstream.
* Sat Sep 19 2020 Matthias Bach <marix@marix.org> - 51
- Following packaging guidelines, exclude static libraries again.
* Fri Sep 18 2020 Matthias Bach <marix@marix.org> - 51
- Execute upstream tests during package build
* Thu Sep 17 2020 Matthias Bach <marix@marix.org> - 51
- Fix the library not matching its soname
* Thu Sep 17 2020 Matthias Bach <marix@marix.org>
- Include static library
* Thu Sep 17 2020 Matthias Bach <marix@marix.org>
- Drop build config only required for SLE11
* Mon Sep 14 2020 Matthias Bach <marix@marix.org>
- Fix broken requirement
* Sat Sep 12 2020 Matthias Bach <marix@marix.org> - 51
- Initial package release
